@@ -9,6 +9,7 @@ import (
 	"path"
 	"path/filepath"
 	"runtime"
+	"strconv"
 	"strings"
 	"time"
 
@@ -35,7 +36,7 @@ func Run() (err error) {
 	app := cli.NewApp()
 	app.Name = "croc"
 	if Version == "" {
-		Version = "v9.6.4-1fce28e"
+		Version = "v9.6.5-8ab65d0"
 	}
 	app.Version = Version
 	app.Compiled = time.Now()
@@ -105,6 +106,7 @@ func Run() (err error) {
 		&cli.StringFlag{Name: "out", Value: ".", Usage: "specify an output folder to receive the file"},
 		&cli.StringFlag{Name: "pass", Value: models.DEFAULT_PASSPHRASE, Usage: "password for the relay", EnvVars: []string{"CROC_PASS"}},
 		&cli.StringFlag{Name: "socks5", Value: "", Usage: "add a socks5 proxy", EnvVars: []string{"SOCKS5_PROXY"}},
+		&cli.StringFlag{Name: "connect", Value: "", Usage: "add a http proxy", EnvVars: []string{"HTTP_PROXY"}},
 		&cli.StringFlag{Name: "throttleUpload", Value: "", Usage: "Throttle the upload speed e.g. 500k"},
 	}
 	app.EnableBashCompletion = true
@@ -169,6 +171,7 @@ func determinePass(c *cli.Context) (pass string) {
 func send(c *cli.Context) (err error) {
 	setDebugLevel(c)
 	comm.Socks5Proxy = c.String("socks5")
+	comm.HttpProxy = c.String("connect")
 	portsString := c.String("ports")
 	if portsString == "" {
 		portsString = "9009,9010,9011,9012,9013"
@@ -365,10 +368,21 @@ func (t TabComplete) Do(line []rune, pos int) ([][]rune, int) {
 		// No completion
 		return [][]rune{[]rune("")}, 0
 	}
+	if len(words) == 1 && nbCharacter == utils.NbPinNumbers {
+		// Check if word is indeed a number
+		_, err := strconv.Atoi(lastPartialWord)
+		if err == nil {
+			return [][]rune{[]rune("-")}, nbCharacter
+		}
+	}
 	var strArray [][]rune
 	for _, s := range mnemonicode.WordList {
 		if strings.HasPrefix(s, lastPartialWord) {
-			strArray = append(strArray, []rune(s[nbCharacter:]))
+			var completionCandidate = s[nbCharacter:]
+			if len(words) <= mnemonicode.WordsRequired(utils.NbBytesWords) {
+				completionCandidate += "-"
+			}
+			strArray = append(strArray, []rune(completionCandidate))
 		}
 	}
 	return strArray, nbCharacter
@@ -376,6 +390,7 @@ func (t TabComplete) Do(line []rune, pos int) ([][]rune, int) {
 
 func receive(c *cli.Context) (err error) {
 	comm.Socks5Proxy = c.String("socks5")
+	comm.HttpProxy = c.String("connect")
 	crocOptions := croc.Options{
 		SharedSecret:  c.String("code"),
 		IsSender:      false,
