@@ -27,6 +27,9 @@ import (
 	"github.com/schollz/mnemonicode"
 )
 
+const NbPinNumbers = 4
+const NbBytesWords = 4
+
 // Get or create home directory
 func GetConfigDir() (homedir string, err error) {
 	homedir, err = os.UserHomeDir()
@@ -186,7 +189,7 @@ func GenerateRandomPin() string {
 	s := ""
 	max := new(big.Int)
 	max.SetInt64(9)
-	for i := 0; i < 4; i++ {
+	for i := 0; i < NbPinNumbers; i++ {
 		v, err := rand.Int(rand.Reader, max)
 		if err != nil {
 			panic(err)
@@ -199,7 +202,7 @@ func GenerateRandomPin() string {
 // GetRandomName returns mnemonicoded random name
 func GetRandomName() string {
 	var result []string
-	bs := make([]byte, 4)
+	bs := make([]byte, NbBytesWords)
 	rand.Read(bs)
 	result = mnemonicode.EncodeWordList(result, bs)
 	return GenerateRandomPin() + "-" + strings.Join(result, "-")
@@ -356,7 +359,7 @@ func init() {
 }
 
 func IsLocalIP(ipaddress string) bool {
-	if strings.Contains(ipaddress, "localhost") {
+	if strings.Contains(ipaddress, "127.0.0.1") {
 		return true
 	}
 	host, _, _ := net.SplitHostPort(ipaddress)
